// Injection Wizard
// --An application for injecting traffic in WEP protected Wi-Fi networks--
// Version: 1.0
// Copyright (C) 2010 Fernando Pablo Romero Navarro <fernpromero@gmail.com>
//This program is free software; you can redistribute it and/or
//modify it under the terms of the GNU General Public License
//as published by the Free Software Foundation; either version 2
//of the License, or (at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

package cliente;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.util.ResourceBundle;
import java.util.HashMap;


public class IfaceDialog extends JDialog{

    public final static int OK=0;
    public final static int BADIFACE=-1;
    public final static int BADFCS=-2;
    public final static int BADHDR=-3;

    private String[] radiolabels=null;
    private boolean validated=false;
    private String[] ifaces=null;
    private ResourceBundle bundle=null;
    private ClientConf conf=null;
    private JComboBox jCbifaces=null;
    private ButtonGroup bgfcs=null;
    private HashMap<ButtonModel, String> fcstext=null;
    private ButtonGroup bghdr=null;
    private HashMap<ButtonModel, String> hdrtext=null;
    private JButton jBtnok=null;
    private JButton jBtncl=null;

    public IfaceDialog(Frame owner, ResourceBundle bundle,
                       String[] ifaces, ClientConf config){
        super(owner, bundle.getString("MENUIFACE"), true);
        this.bundle=bundle;
        this.ifaces=ifaces;
        this.conf=config;
        radiolabels=new String[]{bundle.getString("LABELAUTO"),
                                 bundle.getString("LABELNONE"),
                                 bundle.getString("LABELRDTAP"),
                                 };
        initComponents();
        initListeners();
        pack();
        setResizable(false);
        setLocationRelativeTo(owner);
        setVisible(true);
    }

    public boolean isValidated(){
        return validated;
    }

    public String getSelInterface(){
        return (String)jCbifaces.getSelectedItem();
    }

    public boolean getHasFCS(){
        ButtonModel model=bgfcs.getSelection();
        String label=fcstext.get(model);
        if(label.equals(bundle.getString("LABELYES")))
            return true;
        else
            return false;
    }

    public int getHeaderIndex(){
        ButtonModel model=bghdr.getSelection();
        String label=hdrtext.get(model);
        int i=0;
        while(i<radiolabels.length && !radiolabels[i].equals(label)) i++;
        return i;
    }

    private void initComponents(){
        Dimension dim0=new Dimension(0, 0);
        Container contentPane=getContentPane();
        contentPane.setLayout(new BorderLayout());

        JPanel jPup=new JPanel(new GridLayout(1,2));
        
        JPanel jPcombo=new JPanel();
        jPcombo.setLayout(new BoxLayout(jPcombo, BoxLayout.LINE_AXIS));
        String lb=bundle.getString("LABELIFACE");
        jPcombo.setBorder(BorderFactory.createTitledBorder(lb));        
        
        jCbifaces=new JComboBox(ifaces);
        jCbifaces.setEditable(false);
        lb=bundle.getString("TIPIFACE");
        jCbifaces.setToolTipText(lb);
        jCbifaces.setPreferredSize(new Dimension(100, 40));
        jCbifaces.setBorder(BorderFactory.createEmptyBorder(10, 5, 10, 5));
        String seliface=conf.getIface();
        if(seliface!=null){
            int i=0;
            while (i<ifaces.length && !seliface.equals(ifaces[i])) i++;
            if(i<ifaces.length)
                jCbifaces.setSelectedItem(seliface);
        }
        jPcombo.add(jCbifaces);        
        jPcombo.add(Box.createHorizontalGlue());

        bgfcs=new ButtonGroup();
        fcstext=new HashMap<ButtonModel, String>(2);
        JPanel jPradio=new JPanel(new GridLayout(1,5));
        jPradio.add(Box.createRigidArea(dim0));
        lb=bundle.getString("LABELFCS");
        jPradio.setBorder(BorderFactory.createTitledBorder(lb));
        boolean selected=conf.hasFCS();

        lb=bundle.getString("LABELYES");
        JRadioButton jRbtny=new JRadioButton(lb, selected);
        lb=bundle.getString("TIPFCS");
        jRbtny.setToolTipText(lb);
        bgfcs.add(jRbtny);
        fcstext.put(jRbtny.getModel(), jRbtny.getText());
        jPradio.add(jRbtny);

        jPradio.add(Box.createRigidArea(dim0));
        lb=bundle.getString("LABELNO");
        JRadioButton jRbtnn=new JRadioButton(lb, !selected);
        lb=bundle.getString("TIPFCS");
        jRbtnn.setToolTipText(lb);
        bgfcs.add(jRbtnn);
        fcstext.put(jRbtnn.getModel(), jRbtnn.getText());
        jPradio.add(jRbtnn);
        jPradio.add(Box.createRigidArea(dim0));

        jPup.add(jPcombo);
        jPup.add(jPradio);     
        contentPane.add(jPup, BorderLayout.PAGE_START);

        bghdr=new ButtonGroup();
        hdrtext=new HashMap<ButtonModel,String>(4);
        jPradio=new JPanel(new GridLayout(1, 4));
        lb=bundle.getString("LABELHEADER");
        jPradio.setBorder(BorderFactory.createCompoundBorder(
                            BorderFactory.createTitledBorder(lb),
                            BorderFactory.createEmptyBorder(5, 10, 5, 10)));
        
        int selindex=conf.getHeaderType();       
        int i=0;
        JRadioButton jRbtn=null;
        lb=bundle.getString("TIPHEADER");
        for(String rlbl: radiolabels){
            jRbtn=new JRadioButton(rlbl, i==selindex);
            jRbtn.setToolTipText(lb);
            bghdr.add(jRbtn);
            hdrtext.put(jRbtn.getModel(), rlbl);
            jPradio.add(jRbtn);
            i=i+1;
        }       
        contentPane.add(jPradio, BorderLayout.CENTER);

        JPanel jPbtns=new JPanel(new GridLayout(1, 5));
        jPbtns.setBorder(BorderFactory.createEmptyBorder(25, 15, 20, 15));
        jPbtns.add(Box.createRigidArea(dim0));
        lb=bundle.getString("BUTTONOK");
        jBtnok=new JButton(lb);
        jPbtns.add(jBtnok);
        jPbtns.add(Box.createRigidArea(dim0));
        lb=bundle.getString("BUTTONCANCEL");
        jBtncl=new JButton(lb);
        jPbtns.add(jBtncl);
        jPbtns.add(Box.createRigidArea(dim0));
        contentPane.add(jPbtns, BorderLayout.PAGE_END);
    }

    private void initListeners(){
        setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
        jBtnok.addActionListener(
                new ActionListener(){
                    public void actionPerformed(ActionEvent evt){
                        String errmsg=bundle.getString("ERR_SELECT");
                        String err=bundle.getString("ERR");
                        int valcode=validateInput();
                        
                        if(valcode==BADFCS)
                            errmsg+=" \""+bundle.getString("LABELFCS")+"\"";
                        else if(valcode==BADHDR)
                            errmsg+=" \""+bundle.getString("LABELHEADER")+"\"";
                        else if(valcode==OK)
                            errmsg=null;

                        if(errmsg==null){
                            validated=true;
                            dispose();
                        }else
                            JOptionPane.showMessageDialog(
                                            IfaceDialog.this, errmsg, err,
                                            JOptionPane.ERROR_MESSAGE);
                    }
                });

        jBtncl.addActionListener(
                new ActionListener(){
                    public void actionPerformed(ActionEvent evt){
                        dispose();
                    }
                });
    }

    private int validateInput(){
        if(bgfcs.getSelection()==null)
            return BADFCS;
        else if(bghdr.getSelection()==null)
            return BADHDR;
        else if(jCbifaces.getSelectedIndex()==-1)
            return BADIFACE;
        else
            return OK;
    }
}
